@@ -2,10 +2,9 @@ import cherrypy
 
 
 class Root(object):
-
     @cherrypy.expose
     def text(self):
-        return 'Hello, world!'
+        return "Hello, world!"
 
 
 app = cherrypy.tree.mount(Root())
