@@ -3,6 +3,6 @@ import flask
 app = flask.Flask(__name__)
 
 
-@app.route('/text')
+@app.route("/text")
 def text():
-    return 'Hello, world!'
+    return "Hello, world!"
