@@ -6,12 +6,10 @@ import json
 
 class TextHandler(tornado.web.RequestHandler):
     def get(self):
-        self.write('Hello, world!')
+        self.write("Hello, world!")
 
 
-application = tornado.web.Application([
-    (r"/text", TextHandler),
-])
+application = tornado.web.Application([(r"/text", TextHandler)])
 
 if __name__ == "__main__":
     application.listen(8000)
