@@ -2,6 +2,6 @@ import hug
 from handlers import birthday, hello
 
 
-@hug.extend_api('')
+@hug.extend_api("")
 def api():
     return [hello, birthday]
