@@ -3,10 +3,10 @@ import hug
 
 
 @hug.cli(version="1.0.0")
-def cli(name: 'The name', age: hug.types.number):
+def cli(name: "The name", age: hug.types.number):
     """Says happy birthday to a user"""
     return "Happy {age} Birthday {name}!\n".format(**locals())
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     cli.interface.cli()
