@@ -4,6 +4,6 @@ api = hug.API(__name__)
 api.http.add_middleware(hug.middleware.CORSMiddleware(api, max_age=10))
 
 
-@hug.get('/demo')
+@hug.get("/demo")
 def get_demo():
-    return {'result': 'Hello World'}
+    return {"result": "Hello World"}
