@@ -4,4 +4,4 @@ import hug
 @hug.get()
 def hello(request):
     """Says hellos"""
-    return 'Hello Worlds for Bacon?!'
+    return "Hello Worlds for Bacon?!"
