@@ -3,9 +3,9 @@ import hug
 
 @hug.get()
 def hello_world():
-    return 'Hello world!'
+    return "Hello world!"
 
 
 @hug.not_found()
 def not_found():
-    return {'Nothing': 'to see'}
+    return {"Nothing": "to see"}
