@@ -3,8 +3,8 @@ import hug
 
 @hug.get()
 def quick():
-    return 'Serving!'
+    return "Serving!"
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     hug.API(__name__).http.serve()
