@@ -5,5 +5,4 @@ import hug
 @hug.local()
 def happy_birthday(name: hug.types.text, age: hug.types.number, hug_timer=3):
     """Says happy birthday to a user"""
-    return {'message': 'Happy {0} Birthday {1}!'.format(age, name),
-            'took': float(hug_timer)}
+    return {"message": "Happy {0} Birthday {1}!".format(age, name), "took": float(hug_timer)}
