@@ -4,9 +4,8 @@ import hug
 
 @hug.directive()
 class SMTP(object):
-
     def __init__(self, *args, **kwargs):
-        self.smtp = envelopes.SMTP(host='127.0.0.1')
+        self.smtp = envelopes.SMTP(host="127.0.0.1")
         self.envelopes_to_send = list()
 
     def send_envelope(self, envelope):
@@ -19,12 +18,12 @@ class SMTP(object):
             self.smtp.send(envelope)
 
 
-@hug.get('/hello')
+@hug.get("/hello")
 def send_hello_email(smtp: SMTP):
     envelope = envelopes.Envelope(
-        from_addr=(u'me@example.com', u'From me'),
-        to_addr=(u'world@example.com', u'To World'),
-        subject=u'Hello',
-        text_body=u"World!"
+        from_addr=(u"me@example.com", u"From me"),
+        to_addr=(u"world@example.com", u"To World"),
+        subject=u"Hello",
+        text_body=u"World!",
     )
     smtp.send_envelope(envelope)
