@@ -11,11 +11,9 @@ from demo.models import TestUser, TestModel
 @hug.type(extend=hug.types.text, chain=True, accept_context=True)
 def unique_username(value, context: SqlalchemyContext):
     if context.db.query(
-        context.db.query(TestUser).filter(
-            TestUser.username == value
-        ).exists()
+        context.db.query(TestUser).filter(TestUser.username == value).exists()
     ).scalar():
-        raise ValueError('User with a username {0} already exists.'.format(value))
+        raise ValueError("User with a username {0} already exists.".format(value))
     return value
 
 
@@ -26,22 +24,19 @@ class CreateUserSchema(Schema):
     @validates_schema
     def check_unique_username(self, data):
         if self.context.db.query(
-            self.context.db.query(TestUser).filter(
-                    TestUser.username == data['username']
-            ).exists()
+            self.context.db.query(TestUser).filter(TestUser.username == data["username"]).exists()
         ).scalar():
-            raise ValueError('User with a username {0} already exists.'.format(data['username']))
+            raise ValueError("User with a username {0} already exists.".format(data["username"]))
 
 
 class DumpUserSchema(ModelSchema):
-
     @property
     def session(self):
         return self.context.db
 
     class Meta:
         model = TestModel
-        fields = ('name',)
+        fields = ("name",)
 
 
 class DumpSchema(Schema):
