@@ -35,67 +35,79 @@ from hug.api import API
 from hug.defaults import input_format
 from hug.format import parse_content_type
 
-Response = namedtuple('Response', ('data', 'status_code', 'headers'))
-Request = namedtuple('Request', ('content_length', 'stream', 'params'))
+Response = namedtuple("Response", ("data", "status_code", "headers"))
+Request = namedtuple("Request", ("content_length", "stream", "params"))
 
 
 class Service(object):
     """Defines the base concept of a consumed service.
         This is to enable encapsulating the logic of calling a service so usage can be independant of the interface
     """
-    __slots__ = ('timeout', 'raise_on', 'version')
 
-    def __init__(self, version=None, timeout=None, raise_on=(500, ), **kwargs):
+    __slots__ = ("timeout", "raise_on", "version")
+
+    def __init__(self, version=None, timeout=None, raise_on=(500,), **kwargs):
         self.version = version
         self.timeout = timeout
-        self.raise_on = raise_on if type(raise_on) in (tuple, list) else (raise_on, )
+        self.raise_on = raise_on if type(raise_on) in (tuple, list) else (raise_on,)
 
-    def request(self, method, url, url_params=empty.dict, headers=empty.dict, timeout=None, **params):
+    def request(
+        self, method, url, url_params=empty.dict, headers=empty.dict, timeout=None, **params
+    ):
         """Calls the service at the specified URL using the "CALL" method"""
         raise NotImplementedError("Concrete services must define the request method")
 
     def get(self, url, url_params=empty.dict, headers=empty.dict, timeout=None, **params):
         """Calls the service at the specified URL using the "GET" method"""
-        return self.request('GET', url=url, headers=headers, timeout=timeout, **params)
+        return self.request("GET", url=url, headers=headers, timeout=timeout, **params)
 
     def post(self, url, url_params=empty.dict, headers=empty.dict, timeout=None, **params):
         """Calls the service at the specified URL using the "POST" method"""
-        return self.request('POST', url=url, headers=headers, timeout=timeout, **params)
+        return self.request("POST", url=url, headers=headers, timeout=timeout, **params)
 
     def delete(self, url, url_params=empty.dict, headers=empty.dict, timeout=None, **params):
         """Calls the service at the specified URL using the "DELETE" method"""
-        return self.request('DELETE', url=url, headers=headers, timeout=timeout, **params)
+        return self.request("DELETE", url=url, headers=headers, timeout=timeout, **params)
 
     def put(self, url, url_params=empty.dict, headers=empty.dict, timeout=None, **params):
         """Calls the service at the specified URL using the "PUT" method"""
-        return self.request('PUT', url=url, headers=headers, timeout=timeout, **params)
+        return self.request("PUT", url=url, headers=headers, timeout=timeout, **params)
 
     def trace(self, url, url_params=empty.dict, headers=empty.dict, timeout=None, **params):
         """Calls the service at the specified URL using the "TRACE" method"""
-        return self.request('TRACE', url=url, headers=headers, timeout=timeout, **params)
+        return self.request("TRACE", url=url, headers=headers, timeout=timeout, **params)
 
     def patch(self, url, url_params=empty.dict, headers=empty.dict, timeout=None, **params):
         """Calls the service at the specified URL using the "PATCH" method"""
-        return self.request('PATCH', url=url, headers=headers, timeout=timeout, **params)
+        return self.request("PATCH", url=url, headers=headers, timeout=timeout, **params)
 
     def options(self, url, url_params=empty.dict, headers=empty.dict, timeout=None, **params):
         """Calls the service at the specified URL using the "OPTIONS" method"""
-        return self.request('OPTIONS', url=url, headers=headers, timeout=timeout, **params)
+        return self.request("OPTIONS", url=url, headers=headers, timeout=timeout, **params)
 
     def head(self, url, url_params=empty.dict, headers=empty.dict, timeout=None, **params):
         """Calls the service at the specified URL using the "HEAD" method"""
-        return self.request('HEAD', url=url, headers=headers, timeout=timeout, **params)
+        return self.request("HEAD", url=url, headers=headers, timeout=timeout, **params)
 
     def connect(self, url, url_params=empty.dict, headers=empty.dict, timeout=None, **params):
         """Calls the service at the specified URL using the "CONNECT" method"""
-        return self.request('CONNECT', url=url, headers=headers, timeout=timeout, **params)
+        return self.request("CONNECT", url=url, headers=headers, timeout=timeout, **params)
 
 
 class HTTP(Service):
-    __slots__ = ('endpoint', 'session', 'json_transport')
+    __slots__ = ("endpoint", "session", "json_transport")
 
-    def __init__(self, endpoint, auth=None, version=None, headers=empty.dict, timeout=None, raise_on=(500, ),
-                 json_transport=True, **kwargs):
+    def __init__(
+        self,
+        endpoint,
+        auth=None,
+        version=None,
+        headers=empty.dict,
+        timeout=None,
+        raise_on=(500,),
+        json_transport=True,
+        **kwargs
+    ):
         super().__init__(timeout=timeout, raise_on=raise_on, version=version, **kwargs)
         self.endpoint = endpoint
         self.session = requests.Session()
@@ -103,48 +115,62 @@ class HTTP(Service):
         self.session.headers.update(headers)
         self.json_transport = json_transport
 
-    def request(self, method, url, url_params=empty.dict, headers=empty.dict, timeout=None, **params):
-        url = "{0}/{1}".format(self.version, url.lstrip('/')) if self.version else url
-        kwargs = {'json' if self.json_transport else 'params': params}
-        response = self.session.request(method, self.endpoint + url.format(url_params), headers=headers, **kwargs)
+    def request(
+        self, method, url, url_params=empty.dict, headers=empty.dict, timeout=None, **params
+    ):
+        url = "{0}/{1}".format(self.version, url.lstrip("/")) if self.version else url
+        kwargs = {"json" if self.json_transport else "params": params}
+        response = self.session.request(
+            method, self.endpoint + url.format(url_params), headers=headers, **kwargs
+        )
 
         data = BytesIO(response.content)
-        content_type, content_params = parse_content_type(response.headers.get('content-type', ''))
+        content_type, content_params = parse_content_type(response.headers.get("content-type", ""))
         if content_type in input_format:
             data = input_format[content_type](data, **content_params)
 
         if response.status_code in self.raise_on:
-            raise requests.HTTPError('{0} {1} occured for url: {2}'.format(response.status_code, response.reason, url))
+            raise requests.HTTPError(
+                "{0} {1} occured for url: {2}".format(response.status_code, response.reason, url)
+            )
 
         return Response(data, response.status_code, response.headers)
 
 
 class Local(Service):
-    __slots__ = ('api', 'headers')
+    __slots__ = ("api", "headers")
 
-    def __init__(self, api, version=None, headers=empty.dict, timeout=None, raise_on=(500, ), **kwargs):
+    def __init__(
+        self, api, version=None, headers=empty.dict, timeout=None, raise_on=(500,), **kwargs
+    ):
         super().__init__(timeout=timeout, raise_on=raise_on, version=version, **kwargs)
         self.api = API(api)
         self.headers = headers
 
-    def request(self, method, url, url_params=empty.dict, headers=empty.dict, timeout=None, **params):
+    def request(
+        self, method, url, url_params=empty.dict, headers=empty.dict, timeout=None, **params
+    ):
         function = self.api.http.versioned.get(self.version, {}).get(url, None)
         if not function:
             function = self.api.http.versioned.get(None, {}).get(url, None)
 
         if not function:
             if 404 in self.raise_on:
-                raise requests.HTTPError('404 Not Found occured for url: {0}'.format(url))
-            return Response('Not Found', 404, {'content-type', 'application/json'})
+                raise requests.HTTPError("404 Not Found occured for url: {0}".format(url))
+            return Response("Not Found", 404, {"content-type", "application/json"})
 
         interface = function.interface.http
         response = falcon.Response()
         request = Request(None, None, empty.dict)
-        context = self.api.context_factory(api=self.api, api_version=self.version, interface=interface)
+        context = self.api.context_factory(
+            api=self.api, api_version=self.version, interface=interface
+        )
         interface.set_response_defaults(response)
 
         params.update(url_params)
-        params = interface.gather_parameters(request, response, context, api_version=self.version, **params)
+        params = interface.gather_parameters(
+            request, response, context, api_version=self.version, **params
+        )
         errors = interface.validate(params, context)
         if errors:
             interface.render_errors(errors, request, response)
@@ -152,42 +178,53 @@ class Local(Service):
             interface.render_content(interface.call_function(params), context, request, response)
 
         data = BytesIO(response.data)
-        content_type, content_params = parse_content_type(response._headers.get('content-type', ''))
+        content_type, content_params = parse_content_type(response._headers.get("content-type", ""))
         if content_type in input_format:
             data = input_format[content_type](data, **content_params)
 
-        status_code = int(''.join(re.findall('\d+', response.status)))
+        status_code = int("".join(re.findall("\d+", response.status)))
         if status_code in self.raise_on:
-            raise requests.HTTPError('{0} occured for url: {1}'.format(response.status, url))
+            raise requests.HTTPError("{0} occured for url: {1}".format(response.status, url))
 
         return Response(data, status_code, response._headers)
 
 
 class Socket(Service):
-    __slots__ = ('connection_pool', 'timeout', 'connection', 'send_and_receive')
+    __slots__ = ("connection_pool", "timeout", "connection", "send_and_receive")
 
-    on_unix = getattr(socket, 'AF_UNIX', False)
-    Connection = namedtuple('Connection', ('connect_to', 'proto', 'sockopts'))
+    on_unix = getattr(socket, "AF_UNIX", False)
+    Connection = namedtuple("Connection", ("connect_to", "proto", "sockopts"))
     protocols = {
-        'tcp': (socket.AF_INET, socket.SOCK_STREAM),
-        'udp': (socket.AF_INET, socket.SOCK_DGRAM),
+        "tcp": (socket.AF_INET, socket.SOCK_STREAM),
+        "udp": (socket.AF_INET, socket.SOCK_DGRAM),
     }
-    streams = set(('tcp',))
-    datagrams = set(('udp',))
-    inet = set(('tcp', 'udp',))
+    streams = set(("tcp",))
+    datagrams = set(("udp",))
+    inet = set(("tcp", "udp"))
     unix = set()
 
     if on_unix:
-        protocols.update({
-            'unix_dgram': (socket.AF_UNIX, socket.SOCK_DGRAM),
-            'unix_stream': (socket.AF_UNIX, socket.SOCK_STREAM)
-        })
-        streams.add('unix_stream')
-        datagrams.add('unix_dgram')
-        unix.update(('unix_stream', 'unix_dgram'))
+        protocols.update(
+            {
+                "unix_dgram": (socket.AF_UNIX, socket.SOCK_DGRAM),
+                "unix_stream": (socket.AF_UNIX, socket.SOCK_STREAM),
+            }
+        )
+        streams.add("unix_stream")
+        datagrams.add("unix_dgram")
+        unix.update(("unix_stream", "unix_dgram"))
 
-    def __init__(self, connect_to, proto, version=None,
-                headers=empty.dict, timeout=None, pool=0, raise_on=(500, ), **kwargs):
+    def __init__(
+        self,
+        connect_to,
+        proto,
+        version=None,
+        headers=empty.dict,
+        timeout=None,
+        pool=0,
+        raise_on=(500,),
+        **kwargs
+    ):
         super().__init__(timeout=timeout, raise_on=raise_on, version=version, **kwargs)
         connect_to = tuple(connect_to) if proto in Socket.inet else connect_to
         self.timeout = timeout
@@ -231,8 +268,8 @@ class Socket(Service):
         """TCP/Stream sender and receiver"""
         data = BytesIO()
 
-        _socket_fd = _socket.makefile(mode='rwb', encoding='utf-8')
-        _socket_fd.write(message.encode('utf-8'))
+        _socket_fd = _socket.makefile(mode="rwb", encoding="utf-8")
+        _socket_fd.write(message.encode("utf-8"))
         _socket_fd.flush()
 
         for received in _socket_fd:
@@ -244,7 +281,7 @@ class Socket(Service):
 
     def _dgram_send_and_receive(self, _socket, message, buffer_size=4096, *args):
         """User Datagram Protocol sender and receiver"""
-        _socket.send(message.encode('utf-8'))
+        _socket.send(message.encode("utf-8"))
         data, address = _socket.recvfrom(buffer_size)
         return BytesIO(data)
 
