@@ -5,11 +5,13 @@ import hug
 class FakeSimpleException(Exception):
     pass
 
+
 @hug.get()
 def made_up_hello():
     """for science!"""
-    return 'hello'
+    return "hello"
 
-@hug.get('/exception')
+
+@hug.get("/exception")
 def made_up_exception():
-    raise FakeSimpleException('test')
+    raise FakeSimpleException("test")
