@@ -39,26 +39,33 @@ def test_text():
 def test_json():
     """Ensure that the json input format works as intended"""
     test_data = BytesIO(b'{"a": "b"}')
-    assert hug.input_format.json(test_data) == {'a': 'b'}
+    assert hug.input_format.json(test_data) == {"a": "b"}
 
 
 def test_json_underscore():
     """Ensure that camelCase keys can be converted into under_score for easier use within Python"""
     test_data = BytesIO(b'{"CamelCase": {"becauseWeCan": "ValueExempt"}}')
-    assert hug.input_format.json_underscore(test_data) == {'camel_case': {'because_we_can': 'ValueExempt'}}
+    assert hug.input_format.json_underscore(test_data) == {
+        "camel_case": {"because_we_can": "ValueExempt"}
+    }
 
 
 def test_urlencoded():
     """Ensure that urlencoded input format works as intended"""
-    test_data = BytesIO(b'foo=baz&foo=bar&name=John+Doe')
-    assert hug.input_format.urlencoded(test_data) == {'name': 'John Doe', 'foo': ['baz', 'bar']}
+    test_data = BytesIO(b"foo=baz&foo=bar&name=John+Doe")
+    assert hug.input_format.urlencoded(test_data) == {"name": "John Doe", "foo": ["baz", "bar"]}
 
 
 def test_multipart():
     """Ensure multipart form data works as intended"""
-    with open(os.path.join(BASE_DIRECTORY, 'artwork', 'koala.png'),'rb') as koala:
-        prepared_request = requests.Request('POST', 'http://localhost/', files={'koala': koala}).prepare()
+    with open(os.path.join(BASE_DIRECTORY, "artwork", "koala.png"), "rb") as koala:
+        prepared_request = requests.Request(
+            "POST", "http://localhost/", files={"koala": koala}
+        ).prepare()
         koala.seek(0)
-        file_content = hug.input_format.multipart(BytesIO(prepared_request.body),
-                                                  **parse_header(prepared_request.headers['Content-Type'])[1])['koala']
+        headers = parse_header(prepared_request.headers["Content-Type"])[1]
+        headers["CONTENT-LENGTH"] = "22176"
+        file_content = hug.input_format.multipart(BytesIO(prepared_request.body), **headers)[
+            "koala"
+        ]
         assert file_content == koala.read()
