@@ -28,39 +28,39 @@ import hug.redirect
 def test_to():
     """Test that the base redirect to function works as expected"""
     with pytest.raises(falcon.http_status.HTTPStatus) as redirect:
-        hug.redirect.to('/')
-    assert '302' in redirect.value.status
+        hug.redirect.to("/")
+    assert "302" in redirect.value.status
 
 
 def test_permanent():
     """Test to ensure function causes a redirect with HTTP 301 status code"""
     with pytest.raises(falcon.http_status.HTTPStatus) as redirect:
-        hug.redirect.permanent('/')
-    assert '301' in redirect.value.status
+        hug.redirect.permanent("/")
+    assert "301" in redirect.value.status
 
 
 def test_found():
     """Test to ensure function causes a redirect with HTTP 302 status code"""
     with pytest.raises(falcon.http_status.HTTPStatus) as redirect:
-        hug.redirect.found('/')
-    assert '302' in redirect.value.status
+        hug.redirect.found("/")
+    assert "302" in redirect.value.status
 
 
 def test_see_other():
     """Test to ensure function causes a redirect with HTTP 303 status code"""
     with pytest.raises(falcon.http_status.HTTPStatus) as redirect:
-        hug.redirect.see_other('/')
-    assert '303' in redirect.value.status
+        hug.redirect.see_other("/")
+    assert "303" in redirect.value.status
 
 
 def test_temporary():
     """Test to ensure function causes a redirect with HTTP 307 status code"""
     with pytest.raises(falcon.http_status.HTTPStatus) as redirect:
-        hug.redirect.temporary('/')
-    assert '307' in redirect.value.status
+        hug.redirect.temporary("/")
+    assert "307" in redirect.value.status
 
 
 def test_not_found():
     with pytest.raises(falcon.HTTPNotFound) as redirect:
         hug.redirect.not_found()
-    assert '404' in redirect.value.status
+    assert "404" in redirect.value.status
